<?php
global $event;

register_callback('abc_file_install','plugin_lifecycle.abc_article_image');
add_privs('abc_file', '1,2,3,4,5,6');
add_privs('prefs.abc_file', '1,2,3,4,5,6');

if($event == 'article' && has_privs('image.edit.own'))
{
	register_callback('abc_file_upload', 'article_ui', 'article_image');
	register_callback('abc_file_save', 'article_posted');
	register_callback('abc_file_save', 'article_saved');
	register_callback(function() {
    echo '<link rel="stylesheet" href="'.ahu.'plugins/abc_article_image/css/style.css">'.n;
  }, 'admin_side', 'head_end');
	register_callback('abc_file_js', 'admin_side', 'body_end');
}

register_callback(function($event, $step, $rs) {
  global $img_dir;
  $img = array_intersect_key($rs, array('id' => null, 'alt' => null, 'h' => null, 'w' => null))+
    array('src' => ihu.$img_dir.'/'.$rs['id'].$rs['ext']);
  send_script_response('abcImage = ['.json_encode($img).'].concat(typeof abcImage == "undefined" ? [] : abcImage)');
}, 'site.update', 'image_uploaded');

function abc_file_install($event, $step)
{
    if ($step == 'deleted') {
        safe_delete('txp_prefs', "name LIKE 'abc\_file\_%'");
    } elseif ($step == 'installed') {
        safe_update('txp_prefs', "event='abc_file'", "name LIKE 'abc\_file\_%'");
        if (!get_pref('abc_file_image'))
            set_pref('abc_file_image', '<txp:image id="{#}" />', 'abc_file', PREF_PLUGIN, 'longtext_input', 500, PREF_PRIVATE);
        if (!get_pref('abc_file_link'))
            set_pref('abc_file_link', '', 'abc_file', PREF_PLUGIN, 'longtext_input', 700, PREF_PRIVATE);
        if (!get_pref('abc_file_limit'))
            set_pref('abc_file_limit', 12, 'abc_file', PREF_PLUGIN, 'text_input', 300, PREF_PRIVATE);
    }
}

function abc_file_js($event, $step) {
global $img_dir;
echo script_js(ahu.'plugins/abc_article_image/js/script.js', TEXTPATTERN_SCRIPT_URL, array('article'))
.script_js('var imageTag = "'.escape_js(get_pref('abc_file_image', '<txp:image id="{#}" />')).'",
  imageLink = "'.escape_js(get_pref('abc_file_link')).'",
  imageDir="'.escape_js(ihu.$img_dir).'";', false, array('article'));
}

function abc_file_upload($event, $step, $data, $rs)
{
	$ids = $images = array();
	$fields = 'id, name, ext, thumbnail, alt, h, w';
	if (!empty($rs['Image']))
	{
		$images = array();
		foreach (do_list_unique($rs['Image']) as $id) {
			if (!is_numeric($id))
				$id = (int) fetch('id', 'txp_image', 'name', $id);
			if ($id) {
				$ids[] = $id;
			}
		}
		$id_list = implode(',', $ids);
		$rows = $ids ? safe_rows($fields, 'txp_image', 'id IN ('.$id_list.') ORDER BY FIELD(id, '.$id_list.')') : array();

		foreach ($rows as $row) {
			extract($row);
			$images[] = '<p class="sortable" data-id="'.$id.'"><a href="index.php?event=image&step=image_edit&id='.$id.'" title="'.txpspecialchars($name).' ('.$id.')">'
			.'<img src="'.imagesrcurl($id, $ext, $thumbnail).'" data-id="'.$id.'" data-ext="'.$ext.'" data-width="'.$w.'" data-height="'.$h.'" alt="'.txpspecialchars($alt).'" />'
			.'</a><button class="destroy"><span class="ui-icon ui-icon-close">'.gTxt('delete').'</span></button></p>';
		}
	}

	$article_image = '<div id="article-file-container">'.implode(n, $images).'</div>'.n;

	$images = array();
	$select_images = '';
	$limit = intval(get_pref('abc_file_limit')) or $limit = 12;

	$rows = safe_rows($fields, 'txp_image', ($ids ? 'id NOT IN('.$id_list.')' : '1').' ORDER BY date DESC LIMIT '.$limit);

	foreach ($rows as $row) {
		extract($row);
		$images[] = '<p data-id="'.$id.'"><a href="index.php?event=image&step=image_edit&id='.$id.'" title="'.txpspecialchars($name).' ('.$id.')">'
			.'<img src="'.imagesrcurl($id, $ext, $thumbnail).'" data-id="'.$id.'" data-ext="'.$ext.'" data-width="'.$w.'" data-height="'.$h.'" alt="'.txpspecialchars($alt).'" />'//image(array('id' => $id))
			.'</a><button class="destroy"><span class="ui-icon ui-icon-close">'.gTxt('delete').'</span></button></p>';
	}

	$select_images = '<p class="txp-actions">'
		.'<a id="article-file-add" href="#article-file-select">'.gTxt('add')
		.'<span class="ui-icon ui-icon-arrowthickstop-1-s"></span></a></p>'.n
	.'<div id="article-file-select" class="hidden">'.implode(n, $images).'</div>'.n;

	return $data.n.$article_image.n.'<hr />'.n
	.inputLabel(
		'article-file-input',
		'<button id="article-file-reset" class="destroy"><span class="ui-icon ui-icon-close">'.gTxt('delete').'</span></button>'.n.
		'<input id="article-file-input" type="file" name="article_file[]" multiple="multiple" accept="image/*" onchange="abcPreview(this)" />'
		.'<p>Click or drop files on this zone</p>'.n
		.'<div id="article-file-preview"></div>'.n, gTxt('upload'),
		array('', 'instructions_article_image'),
		array('id' => 'article-file-drop', 'class' => 'txp-form-field article-image')
	).n.'<hr />'.n.$select_images;
}

function abc_file_save($event, $step, $rs)
{
	if(empty($_FILES['article_file']['tmp_name'][0]) || !has_privs('image.edit')) return;

	include_once 'lib'.DIRECTORY_SEPARATOR.'class.thumb.php';
	$ids = array();
	$files = Txp::get('\Textpattern\Server\Files')->refactor($_FILES['article_file']);

	foreach ($files as $file) {
		$meta = array('alt' => $file['name']);  //caption, category
		$img_result = image_data($file, $meta);

		if (is_array($img_result)) {
			list($message, $id) = $img_result;
			$ids[] = $id;
		}
	}

	$GLOBALS['ID'] = intval($rs['ID']);// sic!
	$ids = implode(',', $ids);
	$ids = implode(',', do_list_unique($rs['Image'].','.$ids));
	safe_update('textpattern', "Image='".doSlash($ids)."'", 'ID='.$GLOBALS['ID']);
}